
clear

cd "c:\data"

***********************************************************************************************************
* The spreadsheet education_25.csv contains all of the Barro-Lee data on education for pop older than 25
* The data being from Barro-Lee, covers up to 2010, with 5-year frequency
***********************************************************************************************************

* We use the average educational attainment of people older than 25
insheet using c:\data\education_25.csv, comma n double

drop if year==.

replace country=country[_n-1] if year>1950
replace name=name[_n-1] if year>1950

sort country year

keep country year name avg_25

save education, replace

*************************************************************************************************************

clear

cd "c:\data"

***********************************************************************************************************
* The spreadsheet education_15.csv contains all of the Barro-Lee data on education for pop older than 15
* The data being from Barro-Lee, covers up to 2010, with 5-year frequency
* The missing data is either interpolated or extrapolated
***********************************************************************************************************

* We use the average educational attainment of people older than 25
insheet using c:\data\education_15.csv, comma n double

drop if year==.

replace country=country[_n-1] if year>1950
replace name=name[_n-1] if year>1950

keep country year avg_15

sort country year

merge country year using education.dta

keep country year name avg_15 avg_25

save education, replace

******************************************************************************************************

clear

cd "c:\data"

***********************************************************************************************************
* This program computes the estimate of the series for the capital stock
* The initial capital stock is assumed to be the steady state as computed by Hall & Jones ( QJE 1999), footnote 5 
***********************************************************************************************************

* Load the most recent version of the PWT - This is the raw data
insheet using c:\data\pwt70.csv, comma n double

keep country isocode year rgdpch rgdpwok pop ki ppp xrat

outsheet using pwt70_mod.txt, noquote replace

**********************************************************************

* Input the depreciation rate
gen depr_rate=0.06

* Drop if we do not have data about investment
drop if ki==.

* Compute series of investment per capita
gen investment = rgdpch*ki/100

sort isocode year

* Compute output growth and employment growth for first ten years in sample
by isocode: gen growth_y   =(log(rgdpch[10])-log(rgdpch[1]))/10
by isocode: gen growth_pop =(log(pop[10])-log(pop[1]))/10

* Compute steady state capital per capita
gen denom = exp( growth_y + growth_pop ) - 1 + depr_rate
gen capital = investment/denom
by isocode: replace capital = 0 if _n > 1

* Compute capital per capita in the other years
by isocode: replace capital = (1-depr_rate)*capital[_n-1] + investment if _n > 1

drop growth_y growth_pop denom 

ren country name

rename isocode country

sort country year

save pwt_clean, replace

***********************************************************************************************************

clear

cd "c:\data"

***********************************************************************************************************
* Now we merge the PWT data with the education data
* The data being from Barro-Lee, covers up to 2010, with 5-year frequency
* The missing data is either interpolated or extrapolated
***********************************************************************************************************

* We use the average educational attainment of people older than 25
*insheet using c:\data\education_25.csv, comma n double

use c:\data\education.dta

sort country year

merge country year using pwt_clean

sort country year

* The missing educaiton data is either interpolated or extrapolated
by country: ipolate avg_15 year, gen(education) epolate
by country: ipolate avg_25 year, gen(education_25) epolate

drop if name==""

drop avg_15 avg_25 _merge

gen labor = rgdpch*pop/rgdpwok

keep name country year labor rgdpch rgdpwok pop capital education education_25

ren rgdpwok output_worker
ren rgdpch output_head
ren capital capital_head
ren pop population

drop if population==.

outsheet using pwt_clean.xls, noquote replace

************************* pwt_clean.xls includes all data from the original PWT plus capital and education data

drop if capital==.
drop if education==.
drop if output_worker==.

* Saving as comma-separated spreadsheet
outsheet using pwt_ge.xls, noquote replace

save pwt_ge.dta, replace

**************************** pwt_ge.xls includes only the country-year pairs for which we have data on both capital stock and education

